import os
from azure.identity import DefaultAzureCredential
from azure.keyvault.secrets import SecretClient
from azure.core.exceptions import ResourceNotFoundError

def load_secret(secret_name):
    underscore_name = secret_name.replace("-", "_")
    ev = os.getenv(underscore_name)
    if ev:
        return ev
    
    credential = DefaultAzureCredential()
    key_vault_uri = os.getenv("KEY_VAULT_URI")
    if not key_vault_uri:
        raise Exception("Enviromental Variable KEY_VAULT_URI missing.")
    
    client = SecretClient(vault_url=key_vault_uri, credential=credential)

    dashed_name = secret_name.replace("_", "-")
    try:
        secret_value = client.get_secret(dashed_name).value
        return secret_value
    except ResourceNotFoundError:
        raise ValueError(f"Secret '{dashed_name}' not found in Azure Key Vault.")
    except Exception as e:
        raise RuntimeError(f"Failed to retrieve secret '{dashed_name}' from Azure Key Vault: {str(e)}")



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

VERSION = '0.0.4'
DESCRIPTION = 'A package for loading Azure Key Vault Secrets.'
LONG_DESCRIPTION = 'A package for loading Azure Key Vault Secrets.'

# Setting up
setup(
    name="azkv-secrets-loader",
    version=VERSION,
    author="Richard",
    author_email="<rich_swainson@hotmail.co.uk>",
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[
        'azure-identity' ,
        'azure-keyvault-secrets',
        'azure-core'
    ],
    keywords=['azure', 'api', 'keyvault'],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)